# Discord Self bot wrapper by iFanpS
- Information
    This discord self bot wrapper created because i want to learn how to make API wrapper

    This project is still on progress, so stay tune!

- Creator
    iFanpS
    
    NumeXx

# Requirement
- How to install requirement.txt
    pip install -r requirement.txt